@@ -65,7 +65,7 @@ from . import database
 from . import define_inputs
 from . import evaluate_predictions
 from . import misc
-from . import plot
+from . import plots
 from . import test_data
 from . import main_loop
 from . import gui_start
@@ -73,10 +73,10 @@ from . import gui_start
 from . import main
 
 
-__version__ = "1.37"
+__version__ = "1.39"
 __author__ = "Daniel Malachov"
 __license__ = "MIT"
 __email__ = "malachovd@seznam.cz"
 
 __all__ = ['analyze', 'best_params', 'configuration', 'data_preprocessing', 'database', 'define_inputs',
-           'evaluate_predictions', 'main', 'misc', 'models', 'plot', 'test_data', 'main_loop', 'gui_start']
+           'evaluate_predictions', 'main', 'misc', 'models', 'plots', 'test_data', 'main_loop', 'gui_start']
