@@ -57,8 +57,10 @@ class config():
     data_source = 'test'  # Data source. ('csv', 'txt', 'sql' or 'test') - If sql, you have to edit the query to fit your database.
 
     csv_full_path = r''  # Full CSV path with suffix or web url. Examples: "https://raw.githubusercontent.com/jbrownlee/Datasets/master/daily-min-temperatures.csv" or "/home/dan/ownCloud/Github/predictit_library/predictit/test_data/daily-minimum-temperatures.csv"
-    csv_test_data_relative_path = ''  # CSV name with suffix in test_data folder (E.g. '5000 Sales Records.csv' or 'daily-minimum-temperatures.csv' - !!! gitignored because of size. Download own.)
+    csv_style = {'separator': ",", 'decimal': "."}  # Define CSV separators. En locale usually use {'sep': ",", 'decimal': "."} some Europian country use {'sep': ";", 'decimal': ","}
+
     # !!! Turn it off if not testing to not break csv full path !!! Test data are gitignored... use your own.
+    csv_test_data_relative_path = ''  # CSV name with suffix in test_data folder (E.g. '5000 Sales Records.csv' or 'daily-minimum-temperatures.csv' - !!! gitignored because of size. Download own.)
 
     predicted_column = ''  # Name of predicted column (for dataframe data) or it's index - string or int.
     predicted_columns = []  # For predict_multiple function only! List of names of predicted columns or it's indexes. If 'data' is dataframe or numpy, then you can use ['*'] to predict all the columns with numbers.
@@ -76,15 +78,13 @@ class config():
 
     predicts = 7  # Number of predicted values - 7 by default.
 
-    return_type = 'best'  # 'best', 'all', 'dict', 'models_error_criterion', 'results_dataframe' or 'detailed_results_dictionary'.
-    # 'best' return array of predictions, 'all' return more models
-    # results sorted by how efficient they are. 'results_dataframe' return results and models names in columns. 'detailed_results_dictionary' is used for GUI
-    # and return results as best result, all results, string div with plot and more. 'dict' return models dictionary with al the results. 'models_error_criterion' returns MAPE,
-    # RMSE or DWT(based on config) criterion of all models in array.
+    return_type = 'best'  # 'best', 'all_dataframe', 'detailed_dictionary' or 'models_error_criterion'.
+    # 'best' return array of predictions, 'all_dataframe' return results and models names in columns. 'detailed_dictionary' is used for GUI
+    # and return results as best result, all results, string div with plot and more. 'models_error_criterion' returns MAPE, RMSE or DWT(based on config) criterion of all models in array.
 
     debug = 1  # Debug - If 1, print all results and all the warnings and errors on the way, if 2, stop on first warning, if -1 do not print anything, just return result.
 
-    plot = 1  # If 1, plot interactive graph.
+    plotit = 1  # If 1, plot interactive graph.
     plot_type = 'plotly'  # 'plotly' (interactive) or matplotlib.
     show_plot = 1  # Whether display plot or not. If in jupyter dislplay in jupyter, else in default browser.
     save_plot = 0  # (bool) - Html if plotly type, png if matplotlibtype.
@@ -94,7 +94,7 @@ class config():
     plot_number_of_models = 12  # Number of plotted models. If -1, than all models will be evaluated. 1 if only the best one.
 
     printit = 1  # Turn on and off all printed details at once.
-    print_table = 1  # Whether print table with models errors and time to compute.
+    print_table = 1  # Whether print table with models errors and time to compute. Also for function compare_models.
     print_number_of_models = -1  # How many models will be evaluated and printed in results table. If -1, than all models will be evaluated. 1 if only the best one.
     print_time_table = 1  # Whether print table with models errors and time to compute.
     print_result = 1  # Whether print best model results and model details.
@@ -158,7 +158,10 @@ class config():
     # If using presets - overwriten.
 
     # Comment out models you don't want to use.
-    # Do not comment out input_types, models_input or models_parameters.
+    # Do not comment out input_types, models_input or models_parameters!
+
+    # For more info about models parameters, check it's docstrings or run e.g. `help(predictit.models.sklearn_regression)` in your debug or interactive console
+
     used_models = {
 
         **{model_name: predictit.models.statsmodels_autoregressive for model_name in [
@@ -220,16 +223,18 @@ class config():
             'Autoregressive Linear neural unit', 'Autoregressive Linear neural unit normalized',
             'Linear neural unit with weigths predict', 'Conjugate gradient']},
 
+        **{model_name: 'one_in_one_out' for model_name in [
+            'tensorflow_mlp', 'Sklearn regression one step', 'Bayes ridge regression one step',
+            'Decision tree regression one step', 'Hubber regression one step']},
+
+        # One step not used yet... it's only for multivariate data for predicting just one value
+
         **{model_name: 'batch' for model_name in [
             'Sklearn regression', 'Bayes ridge regression', 'Hubber regression', 'Extra trees regression',
             'Decision tree regression', 'KNeighbors regression', 'Random forest regression',
             'Bagging regression', 'Passive aggressive regression', 'Extreme learning machine',
             'Gen Extreme learning machine', 'Gradient boosting']},
 
-        **{model_name: 'one_step' for model_name in [
-            'tensorflow_mlp', 'Sklearn regression one step', 'Bayes ridge regression one step',
-            'Decision tree regression one step', 'Hubber regression one step']},
-
         'Stochastic gradient regression': 'one_in_batch_out',
         'tensorflow_lstm': 'not_serialized',
 
