@@ -32,7 +32,7 @@ def load_data(config):
                     "\n\nERROR - Test data load failed - You are using relative path. This continue from folder test_data"
                     "in predictit. If you want to use other folder, keep relative_path empty and use absolute csv_full_path.\n\n"))
         try:
-            data = pd.read_csv(config.csv_full_path, header=0).iloc[-config.max_imported_length:, :]
+            data = pd.read_csv(config.csv_full_path, sep=config.csv_style['separator'], decimal=config.csv_style['decimal']).iloc[-config.max_imported_length:, :]
         except Exception:
             raise FileNotFoundError(colorize(f"\n ERROR - Test data load failed - Setup CSV adress and column name in config \n\n"))
 
