@@ -4,8 +4,6 @@ import textwrap
 import os
 from IPython import get_ipython
 import pygments
-import pickle
-from pathlib import Path
 
 _GUI = 0
 
